@@ -12,6 +12,7 @@ import com.fasterxml.jackson.core.format.InputAccessor;
 import com.fasterxml.jackson.core.format.MatchStrength;
 import com.fasterxml.jackson.core.io.IOContext;
 import com.fasterxml.jackson.core.util.VersionUtil;
+
 import com.fasterxml.jackson.dataformat.xml.deser.FromXmlParser;
 import com.fasterxml.jackson.dataformat.xml.ser.ToXmlGenerator;
 import com.fasterxml.jackson.dataformat.xml.util.StaxUtil;
@@ -27,8 +28,7 @@ import com.fasterxml.jackson.dataformat.xml.util.StaxUtil;
 */
 public class XmlFactory extends JsonFactory
 {
-    // For 2.5:
-    private static final long serialVersionUID = 1897624416641000209L;
+    private static final long serialVersionUID = 1; // 2.6
 
     /**
      * Name used to identify XML format
@@ -111,6 +111,10 @@ public class XmlFactory extends JsonFactory
         _cfgNameForTextElement = nameForTextElem;
         if (xmlIn == null) {
             xmlIn = XMLInputFactory.newInstance();
+            // as per [dataformat-xml#190], disable external entity expansion by default
+            xmlIn.setProperty(XMLInputFactory.IS_SUPPORTING_EXTERNAL_ENTITIES, Boolean.FALSE);
+            // and ditto wrt [dataformat-xml#211], SUPPORT_DTD
+            xmlIn.setProperty(XMLInputFactory.SUPPORT_DTD, Boolean.FALSE);
         }
         if (xmlOut == null) {
             xmlOut = XMLOutputFactory.newInstance();
@@ -384,10 +388,10 @@ public class XmlFactory extends JsonFactory
 
     /*
     /**********************************************************
-    /* Capability overrides
+    /* Capability introspection
     /**********************************************************
      */
-    
+
     /**
      * As of 2.4, we do have actual capability for passing char arrays
      * efficiently, but unfortunately
@@ -397,6 +401,16 @@ public class XmlFactory extends JsonFactory
     @Override
     public boolean canUseCharArrays() { return false; }
 
+    @Override // since 2.6
+    public Class<FromXmlParser.Feature> getFormatReadFeatureType() {
+        return FromXmlParser.Feature.class;
+    }
+
+    @Override // since 2.6
+    public Class<ToXmlGenerator.Feature> getFormatWriteFeatureType() {
+        return ToXmlGenerator.Feature.class;
+    }
+
     /*
     /**********************************************************
     /* Overrides of public methods: parsing
